<?php

$LANG = array(

#header.php
'MENU'					=> 'Menu',
'HOME'					=> 'Acuèlh',
'GOTO_CONTENT'			=> 'Anar al contengut',
'GOTO_MENU'				=> 'Anar al menú',
'COMMENTS_RSS_FEEDS'	=> 'Fil Rss dels comentaris',
'COMMENTS'				=> 'Fil dels comentaris',
'ARTICLES_RSS_FEEDS'	=> 'Fil Rss dels articles',
'ARTICLES'				=> 'Fil dels articles',

# sidebar.php
'CATEGORIES' 			=> 'Categorias',
'LATEST_ARTICLES'		=> 'Darrièrs articles',
'LATEST_COMMENTS'		=> 'Darrièrs comentaris',
'ARCHIVES'				=> 'Archius',

# footer.php
'POWERED_BY'			=> 'Generat per',
'PLUXML_DESCRIPTION'	=> 'Blòg o Cms sens basa de donadas',
'IN'					=> 'en',
'ADMINISTRATION'		=> 'Administracion',
'GOTO_TOP'				=> 'Pujar amont',
'TOP'					=> 'Naut de pagina',

# erreur.php
'ERROR'					=> 'La pagina qu’avètz demandada existís pas',
'BACKTO_HOME'			=> 'Tornar a la pagina d’acuèlh',

# common
'WRITTEN_BY'			=> 'Redigit per',
'CLASSIFIED_IN'			=> 'Classat dins',
'TAGS'					=> 'Mots claus',

# commentaires.php
'SAID'					=> 'a dich',
'WRITE_A_COMMENT'		=> 'Escriure un comentari',
'NAME'					=> 'Vòstre nom o pseudò',
'WEBSITE'				=> 'Vòstre siti Internet (facultatiu)',
'EMAIL'					=> 'Vòstre corric (facultatiu)',
'COMMENT'				=> 'Contengut de vòstre messatge',
'CLEAR'					=> 'Escafar',
'SEND'					=> 'Mandar vòstre comentari',
'COMMENTS_CLOSED'		=> 'Los comentaris son barrats',
'ANTISPAM_WARNING'		=> 'Verificacion anti-spam',

'REPLY'					=> 'Respónder',
'REPLY_TO'				=> 'Respónder',
'CANCEL'				=> 'Dirimir',

);

?>
